==> screens-2.0.0.tar.gz: lib/screens.dart <==
library screens;

import 'package:flutter/material.dart';
import 'package:screens/overlay_widget.dart';
import 'package:screens/safe_area_config.dart';
import 'package:screens/custom_overlay.dart';
import 'package:screens/screen_widget.dart';

export 'package:screens/overlay_event.dart';

class Screens {
  final List<Widget> fixedOverlayWidgets;
  final Map<String, CustomOverlay> overlayEvents;
  final CustomOverlay errorOverlay;
  final Widget loaderWidget;

  Screens({
    this.fixedOverlayWidgets,
    this.overlayEvents,
    this.errorOverlay,
    this.loaderWidget,
  });

  ScreenWidget widget({
    GlobalKey<ScaffoldState> scaffoldKey,
    bool showAppBar = false,
    bool isAccent = false,
    bool isStatic = false,
    bool isDefaultScaffold = false,
    String appBarText = '',
    AppBar appBarWidget,
    EdgeInsets padding,
    Widget child,
    List<Widget> children,
    BottomNavigationBar bottomNavigationBar,
    Brightness statusBarBrightness,
    Color backgroundColor,
    SafeAreaConfig safeAreaConfig = const SafeAreaConfig(),
  }) =>
      ScreenWidget(
        scaffoldKey: scaffoldKey,
        showAppBar: showAppBar,
        isAccent: isAccent,
        isStatic: isStatic,
        isDefaultScaffold: isDefaultScaffold,
        appBarText: appBarText,
        appBarWidget: appBarWidget,
        padding: padding,
        child: child,
        children: children,
        bottomNavigationBar: bottomNavigationBar,
        statusBarBrightness: statusBarBrightness,
        backgroundColor: backgroundColor,
        safeAreaConfig: safeAreaConfig,
        errorOverlay: this.errorOverlay,
        loaderWidget: this.loaderWidget,
        overlayEvents: this.overlayEvents,
        fixedOverlayWidgets: this.fixedOverlayWidgets,
      );

  OverlayWidget overlay(Widget widget) => OverlayWidget(
        widget,
        errorOverlay: this.errorOverlay,
        loaderWidget: this.loaderWidget,
        overlayEvents: this.overlayEvents,
        fixedOverlayWidgets: this.fixedOverlayWidgets,
      );
}

==> screens-2.2.0.tar.gz: lib/screens.dart <==
library screens;

import 'package:flutter/material.dart';
import 'package:screens/overlay_widget.dart';
import 'package:screens/safe_area_config.dart';
import 'package:screens/custom_overlay.dart';
import 'package:screens/screen_widget.dart';

export 'package:screens/overlay_event.dart';

class Screens {
  final List<Widget> fixedOverlayWidgets;
  final Map<String, CustomOverlay> overlayEvents;
  final CustomOverlay errorOverlay;
  final Widget loaderWidget;

  Screens({
    this.fixedOverlayWidgets = const [],
    this.overlayEvents = const {},
    this.errorOverlay,
    this.loaderWidget,
  });

  ScreenWidget widget({
    GlobalKey<ScaffoldState> scaffoldKey,
    bool showAppBar = false,
    bool isAccent = false,
    bool isStatic = false,
    bool isDefaultScaffold = false,
    String appBarText = '',
    AppBar appBarWidget,
    EdgeInsets padding,
    Widget child,
    List<Widget> children,
    BottomNavigationBar bottomNavigationBar,
    Brightness statusBarBrightness,
    Color backgroundColor,
    SafeAreaConfig safeAreaConfig = const SafeAreaConfig(),
    List<Widget> fixedOverlayWidgets,
    Map<String, CustomOverlay> overlayEvents,
    CustomOverlay errorOverlay,
    Widget loaderWidget,
  }) =>
      ScreenWidget(
        scaffoldKey: scaffoldKey,
        showAppBar: showAppBar,
        isAccent: isAccent,
        isStatic: isStatic,
        isDefaultScaffold: isDefaultScaffold,
        appBarText: appBarText,
        appBarWidget: appBarWidget,
        padding: padding,
        child: child,
        children: children,
        bottomNavigationBar: bottomNavigationBar,
        statusBarBrightness: statusBarBrightness,
        backgroundColor: backgroundColor,
        safeAreaConfig: safeAreaConfig,
        errorOverlay: errorOverlay ?? this.errorOverlay,
        loaderWidget: loaderWidget ?? this.loaderWidget,
        overlayEvents: this.overlayEvents..addAll(overlayEvents),
        fixedOverlayWidgets: this.fixedOverlayWidgets
          ..addAll(fixedOverlayWidgets),
      );

  OverlayWidget overlay(
    Widget widget, {
    List<Widget> fixedOverlayWidgets,
    Map<String, CustomOverlay> overlayEvents,
    CustomOverlay errorOverlay,
    Widget loaderWidget,
  }) =>
      OverlayWidget(
        widget,
        errorOverlay: errorOverlay ?? this.errorOverlay,
        loaderWidget: loaderWidget ?? this.loaderWidget,
        overlayEvents: this.overlayEvents..addAll(overlayEvents),
        fixedOverlayWidgets: this.fixedOverlayWidgets
          ..addAll(fixedOverlayWidgets),
      );
}
